3 ms·
when turning map into hash_map gives you 30.4% increase in performance, you can't call this an 'extensive' tuning effort... The 'extensive' tuning in the paper
by pilooch 15y ago
when turning map into hash_map gives you 30.4% increase in performance, you can't call this an 'extensive' tuning effort... The 'extensive' tuning in the paper (structure peeling, ...), accounts for minor improvements (< 10% total).
- copper 15y agoThe initial code was supposed to be written in a straightforward way. That said, I was playing around with the code, and using tcmalloc with the original C++ code gives a better speedup (something close to 40% with the provided example.)
- oelewapperke 15y agoBut don't forget that the straightforward C++ was as fast as expertly optimized java (and they mentioned you had to be essentially an expert on the subject of garbage collection internals).
- chrisjsmith 15y agoThat's what I noticed. I think that's called "knowing what you are doing" personally.